@@ -22,11 +22,11 @@ def test_pkginfo_to_metadata(tmp_path):
         ("Provides-Extra", "faster-signatures"),
         ("Requires-Dist", "ed25519ll ; extra == 'faster-signatures'"),
         ("Provides-Extra", "rest"),
-        ("Requires-Dist", "docutils (>=0.8) ; extra == 'rest'"),
+        ("Requires-Dist", "docutils >=0.8 ; extra == 'rest'"),
         ("Requires-Dist", "keyring ; extra == 'signatures'"),
         ("Requires-Dist", "keyrings.alt ; extra == 'signatures'"),
         ("Provides-Extra", "test"),
-        ("Requires-Dist", "pytest (>=3.0.0) ; extra == 'test'"),
+        ("Requires-Dist", "pytest >=3.0.0 ; extra == 'test'"),
         ("Requires-Dist", "pytest-cov ; extra == 'test'"),
     ]
 
